@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2012 Jeffrey Stedfast
+ *  Copyright (C) 2000-2022 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -27,35 +27,35 @@
  *
  * GMime's major version.
  **/
-#define GMIME_MAJOR_VERSION (3)
+#define GMIME_MAJOR_VERSION (3U)
 
 /**
  * GMIME_MINOR_VERSION:
  *
  * GMime's minor version.
  **/
-#define GMIME_MINOR_VERSION (0)
+#define GMIME_MINOR_VERSION (2U)
 
 /**
  * GMIME_MICRO_VERSION:
  *
  * GMime's micro version.
  **/
-#define GMIME_MICRO_VERSION (2)
+#define GMIME_MICRO_VERSION (12U)
 
 /**
  * GMIME_BINARY_AGE:
  *
  * GMime's binary age.
  **/
-#define GMIME_BINARY_AGE    (2)
+#define GMIME_BINARY_AGE    (212U)
 
 /**
  * GMIME_INTERFACE_AGE:
  *
  * GMime's interface age.
  **/
-#define GMIME_INTERFACE_AGE (2)
+#define GMIME_INTERFACE_AGE (4U)
 
 
 /**
